@@ -56,7 +56,6 @@ print MAP '<p><h2>Iconic Barchart with Imagemap</h2>', "\n";
 print MAP '<img src=iconbar.png usemap="#pumpkins">',
 	$$row[1], "\n";
 $dbh->do('DROP TABLE iconic');
-print "iconic barchart OK\n";
 #
 #	simple barchart with imagemap
 #
@@ -75,15 +74,15 @@ WHERE WIDTH=600 AND HEIGHT=600 AND
 	Y-AXIS = 'Y Axis' AND
 	keepOrigin = 1 AND
 	SHOWGRID = 1 AND
-	COLORS=(red, green, blue, yellow, cyan) AND
+	COLORS=red AND
 	X-ORIENT = 'HORIZONTAL' AND
 	MAPNAME = 'barsample' AND
 	MAPURL = 'http://www.presicient.com/samplemap.pl?x=:X&y=:Y' AND
 	MAPTYPE = 'HTML' AND
 	MAPSCRIPT = 'ONCLICK=\"alert(''Got X=:X, Y=:Y'')\"'"
-	) || warn $dbh->errstr, "\n";
+	);
 
-$sth->execute || warn $sth->errstr, "\n";
+$sth->execute;
 $row = $sth->fetchrow_arrayref;
 
 open(BAR, '>samplebar.png');
@@ -96,7 +95,6 @@ print MAP '<p><h2>Simple Barchart with Imagemap</h2>
 print MAP '<img src=samplebar.png usemap="#barsample">',
 	$$row[1], "\n";
 $dbh->do('DROP TABLE barchart');
-print "simple barchart OK\n";
 #
 #	simple boxchart with imagemap
 #
@@ -127,7 +125,6 @@ print MAP '<h2>Boxchart with Imagemap</h2>', "\n";
 print MAP '<img src=samplebox.png usemap="#boxsample">',
 	$$row[1], "\n";
 $dbh->do('DROP TABLE samplebox');
-print "boxchart OK\n";
 #
 #	3-axis barchart
 #
@@ -165,7 +162,6 @@ print MAP '<p><h2>3-Axis Barchart with Imagemap</h2>', "\n";
 print MAP '<img src=bar3axis.png usemap="#sales_by_region">',
 	$$row[1], "\n";
 $dbh->do('DROP table threeaxis');
-print "3 Axis barchart OK\n";
 #
 #	multrange 3D barchart with imagemap
 #
@@ -200,7 +196,6 @@ print MAP '<p><h2>Multirange 3-D Barchart with Imagemap</h2>', "\n";
 print MAP '<img src=samp3dbar.png usemap="#bars3dsample">',
 	$$row[1], "\n";
 $dbh->do('DROP table threedbar');
-print "3-D barchart OK\n";
 #
 #	simple piechart with imagemap
 #
@@ -213,7 +208,6 @@ $sth = $dbh->prepare("SELECT PIECHART, IMAGEMAP FROM samplepie
 WHERE WIDTH=500 AND HEIGHT=500 AND
 	title = 'Sample Pie Chart' AND
 	signature = 'Copyright(C) 2001, Presicient Corp.' AND
-	3-D=1 AND
 	MAPNAME = 'piesample' AND
 	COLORS=(red, green, blue, yellow, gray, marine) AND
 	mapURL = 'http://www.presicient.com/samplemap.pl?x=:X&y=:Y&z=:Z'"
@@ -229,7 +223,6 @@ print MAP '<h2>Piechart with Imagemap</h2>', "\n";
 print MAP '<img src=samplepie.png usemap="#piesample">',
 	$$row[1], "\n";
 $dbh->do('DROP table samplepie');
-print "piechart OK\n";
 #
 #	simple candlestick with imagemap
 #
@@ -258,7 +251,6 @@ close BAR;
 print MAP '<p><h2>Candlestick with Imagemap</h2>', "\n";
 print MAP '<img src=sampcandle.png usemap="#candlesample">',
 	$$row[1], "\n";
-print "candlestick OK\n";
 #
 #	multidomain linegraph with imagemap
 #
@@ -287,7 +279,6 @@ close BAR;
 print MAP '<p><h2>Multirange Linegraph with Imagemap</h2>', "\n";
 print MAP '<img src=samplines.png usemap="#linesample">',
 	$$row[1], "\n";
-print "multirange linegraph OK\n";
 #
 #	multidomain pointgraph with imagemap
 #
@@ -314,7 +305,6 @@ close BAR;
 print MAP '<p><h2>Multirange Pointgraph with Imagemap</h2>', "\n";
 print MAP '<img src=samppoints.png usemap="#pointsample">',
 	$$row[1], "\n";
-print "multirange pointgraph OK\n";
 #
 #	multirange areagraph with imagemap
 #
@@ -350,7 +340,6 @@ print MAP '<img src=samparea.png usemap="#areasample">',
 
 print MAP '</body></html>';
 close MAP;
-print "multirange areagraph OK\n";
 
 $dbh->disconnect;
 
